@@ -1,5 +1,6 @@
 from opyoid.bindings.binding import Binding
 from opyoid.bindings.binding_to_provider_adapter import BindingToProviderAdapter
+from opyoid.bindings.registered_binding import RegisteredBinding
 from opyoid.injection_state import InjectionState
 from opyoid.provider import Provider
 from opyoid.target import Target
@@ -14,6 +15,6 @@ class ClassBindingToProviderAdapter(BindingToProviderAdapter[ClassBinding]):
     def accept(self, binding: Binding[InjectedT], state: InjectionState) -> bool:
         return isinstance(binding, ClassBinding)
 
-    def create(self, binding: ClassBinding[InjectedT], state: InjectionState) -> Provider:
-        new_target = Target(binding.bound_type, binding.annotation)
+    def create(self, binding: RegisteredBinding[ClassBinding[InjectedT]], state: InjectionState) -> Provider:
+        new_target = Target(binding.raw_binding.bound_type, binding.raw_binding.annotation)
         return state.provider_creator.get_provider(new_target, state)
